# Table of Contents

- [executive-kpis](<./executive-kpis.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Executive KPIs](<./Executive-KPIs.md>)
  - [Was this page helpful?](<./Executive-KPIs/Was-this-page-helpful.md>)
